@@ -35,7 +35,8 @@ c	(->	------------------------------------
 	integer       InitRN       !1  Initial random number seed. 2 integers.
 	integer       EventNo      !2  cumulative event number counter.
 	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
-	integer       DestEventNo    !1  Final event no. to be generated.
+	integer       DestEventNo    !1 2 integers: Final event no. to be generated and events to be generated
+                                     !  in the current run.
 	logical       Hidden         !1  Make T, if hidden parameters are to be written.
 	integer	      TempDev	   !2  Logical Dev. number for temporary disk use.
 	integer       PrevEventNo  !2  The event number already finished.  System use for Cont job.
@@ -55,7 +56,7 @@ c	<-)	-------------------------------------
 	common /Zmanagerpc/
      *  BaseTime,  BaseErg, BasePower, Within, 
      *  ErrorOut, Cont, InitRN(2), 
-     *  EventsInTheRun, DestEventNo, Hidden, TempDev, 
+     *  EventsInTheRun, DestEventNo(2), Hidden, TempDev, 
      *  PrevEventNo, SeedFileDev, EventNo
 
 
