@@ -15,5 +15,5 @@ c         by putting  Es = 0.
      +, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE, Mudirp, MulLow
      +, NoOfSites2, OffsetHeight, PathLimit, PrevEventNo, PtAvFrag
      +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev
-     +, SucPw, TempDev, TraceDev, Truncc, Truncn, Truncx, UpsilonMin
-     +, X0
+     +, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn, Truncx
+     +, UpsilonMin, X0
