@@ -12,7 +12,8 @@ c              eventLoop
       record /track/ incident
       integer jold
 
-      do while (EventNo .lt.  DestEventNo)
+      do while (EventNo .lt.  DestEventNo(1) .and. 
+     *      EventsInTheRun .lt. DestEventNo(2))
          EventsInTheRun = EventsInTheRun + 1
          EventNo = EventNo + 1
 c             switch to the random number generator 1
